Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Lookout for Metrics.

Actions, resources, and condition keys for Amazon Lookout for Metrics - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Lookout for Metrics

Amazon Lookout for Metrics (service prefix: `lookoutmetrics` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon Lookout for Metrics
- Resource types defined by Amazon Lookout for Metrics
- Condition keys for Amazon Lookout for Metrics

## Actions defined by Amazon Lookout for Metrics

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
ActivateAnomalyDetector | Grants permission to activate an anomaly detector | Write | AnomalyDetector* |  |
BackTestAnomalyDetector | Grants permission to run a backtest with an anomaly detector | Write | AnomalyDetector* |  |
CreateAlert | Grants permission to create an alert for an anomaly detector | Write | Alert* |  |
AnomalyDetector* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateAnomalyDetector | Grants permission to create an anomaly detector | Write | AnomalyDetector* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateMetricSet | Grants permission to create a dataset | Write | AnomalyDetector* |  |
MetricSet* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeactivateAnomalyDetector | Grants permission to deactivate an anomaly detector | Write | AnomalyDetector* |  |
DeleteAlert | Grants permission to delete an alert | Write | Alert* |  |
DeleteAnomalyDetector | Grants permission to delete an anomaly detector | Write | AnomalyDetector* |  |
DescribeAlert | Grants permission to get details about an alert | Read | Alert* |  |
DescribeAnomalyDetectionExecutions | Grants permission to get information about an anomaly detection job | Read | AnomalyDetector* |  |
DescribeAnomalyDetector | Grants permission to get details about an anomaly detector | Read | AnomalyDetector* |  |
DescribeMetricSet | Grants permission to get details about a dataset | Read | MetricSet* |  |
DetectMetricSetConfig | Grants permission to detect metric set config from data source | Write | AnomalyDetector* |  |
GetAnomalyGroup | Grants permission to get details about a group of affected metrics | Read | AnomalyDetector* |  |
GetDataQualityMetrics | Grants permission to get data quality metrics for an anomaly detector | Read | AnomalyDetector* |  |
GetFeedback | Grants permission to get feedback on affected metrics for an anomaly group | Read | AnomalyDetector* |  |
GetSampleData | Grants permission to get a selection of sample records from an Amazon S3 datasource | Read |  |  |
ListAlerts | Grants permission to get a list of alerts for a detector | List | AnomalyDetector |  |
ListAnomalyDetectors | Grants permission to get a list of anomaly detectors | List |  |  |
ListAnomalyGroupRelatedMetrics | Grants permission to get a list of related measures in an anomaly group | List | AnomalyDetector* |  |
ListAnomalyGroupSummaries | Grants permission to get a list of anomaly groups | List | AnomalyDetector* |  |
ListAnomalyGroupTimeSeries | Grants permission to get a list of affected metrics for a measure in an anomaly group | List | AnomalyDetector* |  |
ListMetricSets | Grants permission to get a list of datasets | List | AnomalyDetector |  |
ListTagsForResource | Grants permission to get a list of tags for a detector, dataset, or alert | Read | Alert |  |
AnomalyDetector |  |
MetricSet |  |
PutFeedback | Grants permission to add feedback for an affected metric in an anomaly group | Write | AnomalyDetector* |  |
TagResource | Grants permission to add tags to a detector, dataset, or alert | Tagging | Alert |  |
AnomalyDetector |  |
MetricSet |  |
| aws:TagKeys aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} |
UntagResource | Grants permission to remove tags from a detector, dataset, or alert | Tagging | Alert |  |
AnomalyDetector |  |
MetricSet |  |
| aws:TagKeys |
UpdateAlert | Grants permission to update an alert for an anomaly detector | Write | Alert* |  |
UpdateAnomalyDetector | Grants permission to update an anomaly detector | Write | AnomalyDetector* |  |
UpdateMetricSet | Grants permission to update a dataset | Write | MetricSet* |  |

## Resource types defined by Amazon Lookout for Metrics

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
AnomalyDetector | `arn:$ { Partition}:lookoutmetrics:$ { Region}:$ { Account}:AnomalyDetector:$ { AnomalyDetectorName}` | aws:ResourceTag/${TagKey}
MetricSet | `arn:$ { Partition}:lookoutmetrics:$ { Region}:$ { Account}:MetricSet/$ { AnomalyDetectorName}/$ { MetricSetName}` | aws:ResourceTag/${TagKey}
Alert | `arn:$ { Partition}:lookoutmetrics:$ { Region}:$ { Account}:Alert:$ { AlertName}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon Lookout for Metrics

Amazon Lookout for Metrics defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters access by the tags associated with the resource | String
aws:TagKeys | Filters access by the tag keys that are passed in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.